@@ -8,7 +8,7 @@
 
 $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going to work
 
-@sweeps = ( [ [ 1, 2, 3, 4, 5, 6 ] ] );
+@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
 # DESCRIPTION OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. # THE NUMBERS ARE THE VARIABLE NUMBERS.
 # MORE THAN ONE SEARCH MAY BE LISTED. # EACH BLOCK SEARCH IS DESCRIBED AS A SEQUENCE OF LIST VARIABLES.
 # THIS IS THE BLOCK SEARCH STRUCTURE DECLARED EXPLICITLY AS AN ALTERNATIVE TO USING @chanceseed AND @caseseed.
@@ -16,11 +16,11 @@ $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4 } );
+@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4, 7 => 1 } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
@@ -324,7 +324,7 @@ $vals{1}{6}{applytype} = [ [ "rotate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #
 # "change_groundreflectance", "genchange"
 $vals{1}{6}{general_variables} = 
 [
-"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
+"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
 $vals{1}{6}{rotate} = 
@@ -336,33 +336,34 @@ $vals{1}{6}{rotate} =
 # [ # rotate obstructions? "y" o "n", # swing of rotation (HALF SWING, SWING MEASURED ON ONE SIDE WITH REGARDS TO THE MIDDLE) 
 # update radiation calculation with the "ish" module?  "b" for yes and "c" for no, continue, # vertex around which to rotate ]
 ##### @applytype111 = (["rotation", "file_name", "target_file_name", "zone_letter"]);
-$vals{1}{6}{recalculateish} = [["y"]]; 
+
+
+######################### PARAMETER 7. #############################
+
+$vals{1}{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
+# "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange"
+$vals{1}{7}{general_variables} = 
+[
+"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
+"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
+];
+$vals{1}{7}{change_groundreflectance} =  
+[ 
+[ 0.20, [ 0, 0.60 ] ] # [ base value, [ low_change, high_change ] ]; OR: [ base value, half-range ];
+];
+$vals{1}{7}{recalculateish} = [["y"]]; 
 ## recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
-$vals{1}{111}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
-[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
-[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
-$vals{1}{111}{use_modish} = 
+$vals{1}{7}{use_modish} = 
 [
 [
 [ 1, "/zones/box.shd", 7 ]
 ]
 ]; 
-
-######################### PARAMETER 7. #############################
-
-#$vals{1}{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
-## the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
-## "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
-## "change_groundreflectance", "genchange"
-#$vals{1}{7}{general_variables} = 
-#[
-#"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-#"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-#];
-#$vals{1}{7}{change_groundreflectance} =  
-#[ 
-#[ 20, [ 20, 50 ] ] # [ base value, [ low, high ] ]; OR: [ base value, half-range ];
-#];
+#$vals{1}{7}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
+#[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
+#[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
 
 
 ######################### PARAMETER 8. #############################
@@ -563,7 +564,6 @@ $vals{1}{111}{translate_vertices} =
 [ "a", "i", "0\ny", "j",  "b", "f", "k", "l", "e",  "d", "0\nr", "0\na", "0\nq", "c", "g", "0\nt", "0\ns", "h" ],  
 [ [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0],  [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0] ], 
 [ "/zones/zone.geo" ], # source file
-[ "y" ] # long menus?
 ],
 ];
 # [ @vertexes_to_transl, Consider that after "p" you have to write "0\nq" ]
@@ -649,7 +649,6 @@ $vals{1}{111}{warp} =
 [ "a" , "d" , "e", "h" , "b" , "c", "f", "g" , "d" , "a" , "h", "e" , "c" , "b", "g", "f" ], # pairs of vertices defining axes
 [ "g", "i" ], # windows to be realigned
 "/zones/zone.geo", # zone geometry file
-"y" # long menus occurring in ESP-r? "y" or "n".
 ], 
 ];
 
@@ -676,7 +675,6 @@ $vals{1}{111}{reshape_windows} = [
 [ ( 40/100 ) ], # windows percentage base value
 [ ( 30/100 )], # windows percentage swing
 [ "k", "l", "m", "n" ], # vertex number of the windows to change
-[ "y" ] # there are long menus for items in ESP-r here? "y" or "n".
 ]
 ],
 ]; 
@@ -691,7 +689,6 @@ $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE
 [216], # base values
 [ "/opts/default_configfile_control_constraints.pl" ], # swing values: still unused
 [ "e", "f", "g", "h", "0\nb\nb" , "0\nb\nd", "0\nb0\nb\nf", "0\nb\n0\nb\nh", "0\nb\n0\nb\nj" ], # letters of vertices in the esp-r geometry file. Here the letters have to be specified corresponding to the vertices whose position has to be changes through propagation of constraints.
-"y" # do you have long menus for items in ESP-r here? "y" or "n".
 ],
 ]; 
 
@@ -699,13 +696,14 @@ $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE
 $vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", but more general, because the propagation here criteria has to be specified in the configuration file. 
 [  
 [
+[
 "/zones/zone.geo", # source file
 "/zones/zone.geo", # target file
 "/opts/default_configfile_geometry_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
 [ "k", "l", "m", "n" ], # vertex letters to be changed.
-"y", # long vertex letters (long menus) in ESP-r here? "y" or "n"
 [ 1, 1, 2, 1 ], # swings, corresponding point to point to vertexletters
 ], # THIS IS THE FIRST OPERATION IN SERIES. OTHER CAN BE ADDED.
+]
 ]; #
 ## THIS VARIABLE REGARDS GEOMETRY USER-IMPOSED CONSTRAINTS
 ## THIS CONSTRAINT CONFIGURATION FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
@@ -725,12 +723,14 @@ $vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", bu
 $vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstructions.
 [ 
 [
+[
 "a", # zone letter
 "/zones/zone.geo", # source file
 "/zones/zone.geo", # target file
 "/opts/default_configfile_obstruction_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
 [  "e", "f", "g", "h" ], # obstruction letters to be changed.
 "y" # act on construction too? "y" or "n". Note that constructions letters (as they appear in the construction database) and not construction names have to be given in the configuration files.
+],
 ], 
 ];
 ## THIS PART REGARDS USER-IMPOSED CONSTRAINTS ABOUT OBSTRUCTIONS
@@ -756,6 +756,7 @@ $vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstr
 
 
 $vals{1}{111}{vary_controls} = 
+[
 [ 
 [
 "/ctl/cell.ctl", # source file
@@ -792,16 +793,19 @@ $vals{1}{111}{vary_controls} =
 [ "f", "a", 0, 1, 0, 0 ], # SECOND LOOP AND FIRST CONTROL FOR THE SECOND LOOP FOR NETS; THEN BEGINNING HOUR SWING, SETPOINT SWING, ON-OFF (-1 OR 1), FRACTION
 ] # END OF NET CONTROLS
 ], # END OF DATA FOR THE FIRST SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE, ETC. NEW SEQUENCES CAN BE ADDED.
+]
 ];
 
 
 $vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 [
 [
+[
 "/ctl/cell.ctl", # source file
 "/ctl/cell.ctl", # target file
 "/opts/default_configfile_control_constraints.pl", # config file 
 ],
+],
 ];
 ## THIS VARIABLE REGARDS CONTROL USER-IMPOSED CONSTRAINTS
 ## THIS CONSTRAINT CONFIGURATION FILE FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
@@ -832,6 +836,7 @@ $vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 ## WITH THE FOLLOWING VARIABLES: @letters AND @period_letters
 
 $vals{1}{111}{vary_net} = 
+[
 [ 
 [
 "/nets/cell.afn", # source file
@@ -880,6 +885,7 @@ $vals{1}{111}{vary_net} =
 ], # END OF THE THIRD COMPONENT
 ] # END OF NET COMPONENTS
 ], # END OF DATA FOR THE FIRST SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE, ETC. NEW SEQUENCES CAN BE ADDED.
+],
 ]; # If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
 ## WITH THE FOLLOWING VARIABLES:
 ## @node_letters AND @component_letters 
@@ -887,6 +893,7 @@ $vals{1}{111}{vary_net} =
 $vals{1}{111}{constrain_net} = 
 [
 [
+[
 "/nets/cell.afn", # source file
 "/nets/cell.afn", # target file
 "/opts/default_configfile_net_constraints.pl", # config file 
@@ -896,6 +903,7 @@ $vals{1}{111}{constrain_net} =
 # ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED.  THE EXCEEDING ITEMS WILL NOT BE USED. 
 # ALSO, THESE VALUES WILL NOT BE USED IF DIFFERENT ONES WILL BE CALCULATED THROUGH PROPAGATION OF CONSTRAINTS, DEPENDING ON THE INSTRUCTIONS IN THE CONFIG FILE
 ], 
+],
 ]; 
 ## THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
 ## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
@@ -935,7 +943,9 @@ $vals{1}{111}{constrain_net} =
 ## @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
 
 
-$vals{1}{111}{propagate_constraints} = [ 
+$vals{1}{111}{propagate_constraints} = 
+[
+[ 
 [
 [ "read_geo", # what to do
 "/zones/zone.geo", # source file
@@ -998,6 +1008,7 @@ $vals{1}{111}{propagate_constraints} = [
 "n" # act on materials too? "y" or "n". That materials letters (as they appear in the material database) and not materials names have to be given in the configuration files.
 ]
 ],
+],
 ]; # THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
 ## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
 ## THIS FILE ALLOWS TO MANIPULATE COMPOUND USER-IMPOSED CONSTRAINTS.
