@@ -62,7 +62,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.47.11'; # our $VERSION = '';
+$VERSION = '0.47.14'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -1017,7 +1017,7 @@ sub exe
 sub start
 {
 ###########################################
-print "THIS IS Sim::OPT,
+print "THIS IS Sim::OPT (version 0.47.14),
 a morphing and optimizazion program.
 
 .  .  .  .  .  .  .  .  .  .  .  .  .
@@ -1038,12 +1038,10 @@ sub opt
 
 	
 	&start;
-	# eval `cat $configfile`; # The file where the program data are
 
 	require $configfile;
-	#if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
 	if ( not ( $tofile ) ) { 
-		unless ( $dowhat{system} eq "windows" )
+		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 		{
 			$tofile = "$mypath/$file-tofile.txt"; 
 		}
