@@ -498,7 +498,7 @@ sub descend
 		push ( @{ $uplift[$countcase][$countblock] }, $winnerval); say TOFILE "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
 		
 		my $message;
-		unless ( $dowhat{system} eq "windows" ) 
+		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 		{
 			$message = "$mypath/attention.txt";
 		}
