@@ -694,7 +694,7 @@ sub report # This function retrieves the results of interest from the texts file
 		open( REPLIST, ">>$replist" ) or die( "$!" ); say TOFILE "dump---(\$replist): " . dump($replist) . "\n\n";  
 		open( REPBLOCK, ">>$repblock" ) or die( "$!" ); say TOFILE "dump---(\$repblock): " . dump($repblock) . "\n\n";
 		
-		unless ( $dowhat{system} eq "windows" ) 
+		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 		{
 			$repfile = "$mypath/$file-report-$countcase-$countblock.txt";  say TOFILE "dump---(\$repfile): " . dump($repfile) . "\n\n";
 		}
