@@ -199,17 +199,7 @@ sub sim    # This function launch the simulations in ESP-r
 				my $tooltype = $dowhat{simtools}{$counttool}; say TOFILE "\$tooltype " . dump( $tooltype );
 				
 				if ( $tooltype eq "esp-r" )
-				{	
-					my $launchline;
-					unless ( $dowhat{system} eq "windows" ) 
-					{
-						$launchline = "-file $simelt/cfg/$fileconfig -mode script";
-					}
-					else
-					{
-						$launchline = "-file $simelt\\cfg\\$fileconfig -mode script";
-					}
-					
+				{					
 					say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
 					say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
 					say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
@@ -275,7 +265,7 @@ sub sim    # This function launch the simulations in ESP-r
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile and $flfile." ;
 									my $printthis =	
-"bps $launchline<<XXX
+"bps -file $simelt$fileconfig -mode script<<XXX
 
 c
 $resfile
@@ -312,7 +302,7 @@ XXX
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile. " ;
 									my $printthis =
-"bps $launchline<<XXX
+"bps -file $simelt$fileconfig -mode script<<XXX
 
 c
 $resfile
@@ -374,7 +364,7 @@ $printthis
 						my $epresroot = $tempname . $epnewfragment ; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
 						
 						my $epnewpath;
-						unless ( $dowhat{system} eq "windows" ) 
+						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 						{ 
 							$epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
 						}
@@ -387,7 +377,7 @@ $printthis
 						my @changes = @simdos[ 12..$#simdos ]; say TOFILE "dump(\@changes ): " . dump( @changes ); 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
-							unless ( $dowhat{system} eq "windows" ) 
+							unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 							{
 								$outputdir = "/Output";
 							}
@@ -428,7 +418,7 @@ $printthis
 						my $simelt = $mypath . "$outputdir"; #say TOFILE "dump(\$simelt ): " . dump( $simelt ); 
 						
 						my $resfile;
-						unless ( $dowhat{system} eq "windows" ) 
+						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 						{
 							$resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
 						}
@@ -500,7 +490,7 @@ $printthis
 										{
 										
 										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf );
-										unless ( $dowhat{system} eq "windows" ) 
+										unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 										{
 											$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
 											$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
@@ -515,7 +505,7 @@ $printthis
 										`runenergyplus $templaunch $epwfile`;
 										#`rm -f $templaunch`;
 									}
-									unless ( $dowhat{system} eq "windows" ) 
+									unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 									{
 										print TOFILE "cp -f $epnewpath $templaunch\n";
 									}
